==> PythonApi_CogentDataHub-0.1.tar.gz: PythonApi_CogentDataHub-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'PythonApi_CogentDataHub',         # How you named your package folder (MyLib)
  packages = ['PythonApi_CogentDataHub'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Python Api for Cogent DataHub',   # Give a short description about your library
  author = 'Colin Yuen',                   # Type in your name
  author_email = 'colin.yuen@skkynet.com',      # Type in your E-Mail
  url = 'https://github.com/cyuenSkkynet/PythonApi',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/cyuenSkkynet/PythonApi/archive/refs/tags/V0.01.tar.gz',    # I explain this later on
  keywords = ['Cogent', 'DataHub', 'Api', 'Python'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'DataHubAPI',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Programming Language :: Python :: 3.12',
  ],
)

==> PythonApi_CogentDataHub-0.3.tar.gz: PythonApi_CogentDataHub-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'PythonApi_CogentDataHub',         # How you named your package folder (MyLib)
  packages = ['PythonApi_CogentDataHub'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Python Api for Cogent DataHub',   # Give a short description about your library
  author = 'Colin Yuen',                   # Type in your name
  author_email = 'colin.yuen@skkynet.com',      # Type in your E-Mail
  url = 'https://github.com/cyuenSkkynet/PythonApi_CogentDataHub',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/cyuenSkkynet/PythonApi_CogentDataHub/archive/refs/tags/v0.03.tar.gz',    # I explain this later on
  keywords = ['Cogent', 'DataHub', 'Api', 'Python'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'DataHubAPI',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Programming Language :: Python :: 3.12',
  ],
)
